library own_keyboard;

import 'package:flutter/material.dart';

class OwnKeyBoard extends StatefulWidget {
  final TextEditingController controller;
  Color? backgroundColor;
  EdgeInsets? padding;
  TextStyle textStyle;
  double iconSize;
  Color? iconBackspaceColor;
  Color? iconDoneColor;
  Color? splashColor;
  VoidCallback? doneClicked;
  VoidCallback? clearClicked;

  OwnKeyBoard(
      {Key? key,
      required this.controller,
      this.backgroundColor = Colors.white10,
      this.padding = const EdgeInsets.all(5),
      this.iconBackspaceColor = Colors.red,
      this.iconDoneColor = Colors.green,
      this.splashColor = Colors.black26,
      this.doneClicked,
      this.clearClicked,
      this.iconSize = 25,
      this.textStyle = const TextStyle()})
      : super(key: key);

  @override
  _OwnKeyBoardState createState() => _OwnKeyBoardState();
}

class _OwnKeyBoardState extends State<OwnKeyBoard> {
  List<int> keys = [1, 2, 3, 4, 5, 6, 7, 8, 9, -2, 0, -1];

  @override
  Widget build(BuildContext context) {
    return Container(
      color: widget.backgroundColor,
      padding: widget.padding,
      child: GridView.builder(
        shrinkWrap: true,
        physics: const NeverScrollableScrollPhysics(),
        itemCount: keys.length,
        gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: 3, childAspectRatio: 2),
        itemBuilder: (_, index) {
          int value = keys[index];
          return InkWell(
            splashColor: widget.splashColor,
            focusColor: Colors.transparent,
            highlightColor: Colors.transparent,
            child: Center(
              child: value == -2
                  ? Icon(
                      Icons.backspace_outlined,
                      size: widget.iconSize,
                      color: widget.iconBackspaceColor,
                    )
                  : value == -1
                      ? Icon(
                          Icons.arrow_forward_outlined,
                          color: widget.iconDoneColor,
                          size: widget.iconSize,
                        )
                      : Text(
                          '$value',
                          style: widget.textStyle,
                        ),
            ),
            onTap: () {
              if (value == -1) {
                //done button clicked
                if (widget.doneClicked != null) {
                  widget.doneClicked!.call();
                }
              } else if (value == -2) {
                //clear button clicked
                if (widget.clearClicked != null) {
                  widget.clearClicked!.call();
                }
                if (widget.controller.text.isNotEmpty) {
                  widget.controller.text = widget.controller.text
                      .substring(0, widget.controller.text.length - 1);
                }
              } else {
                widget.controller.text += "$value";
              }
            },
          );
        },
      ),
    );
  }
}
